<?php
if ( post_password_required() ) { return; }
?>
<div class="single-post-comments">
	<h4 class="widget-title">
		<span>
		<?php
			printf(_n('%1$s comment', '%1$s comments',
		        get_comments_number(), 'luxicar-lite'),
		      	get_comments_number()); ?>
		</span>
	</h4>

	<div class="single-post-comments-content">
		<ul class="rs-ul">
		    <?php
		    wp_list_comments(array(
		        'walker' => null,
		        'style' => 'ul',
		        'short_ping' => true,
		        'callback' => 'luxicar_lite_comment_list',
		        'type' => 'all'
		        ));
		    ?>
	    </ul>

	    <?php if (get_comment_pages_count() > 1 && get_option('page_comments')) : ?>
	    	<div class="comments-pagination">
	    		<?php
	    		paginate_comments_links(array(
	    			'prev_text' => esc_html__('Prev', 'luxicar-lite'),
	    			'next_text' => esc_html__('Next', 'luxicar-lite'),
	    			'type'      => 'list',
	    			'prev_next' => True,
	    			));
	    		paginate_comments_links();
	    		?>
	    	</div>
	    <?php endif; ?>

	    <?php if (!comments_open() && get_comments_number()) : ?>
	    	<blockquote><?php esc_html_e('Comments are closed.', 'luxicar-lite'); ?></blockquote>
	    <?php endif; ?>
	</div>
</div>
<!-- /.single-post-comments -->
<?php luxicar_lite_comment_form(); ?>

<?php
function luxicar_lite_comment_list($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment; ?>
  	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
	    <div class="entry-item">
	      	<div class="entry-thumb">
	        	<a href="<?php echo esc_url($comment->comment_author_url); ?>" target="_blank"><?php echo get_avatar($comment->comment_author_email, 70); ?></a>
	    	</div>
	    	<div class="entry-box">
	    		<span class="entry-meta">
	    			<a href="<?php echo esc_url($comment->comment_author_url); ?>" class="author-name"><?php echo esc_html($comment->comment_author); ?></a>
	    			<span class="entry-time">
	    				<?php comment_date(get_option('date_format') ); ?>
	        			<?php esc_html_e('at ', 'luxicar-lite');?>
	        			<?php comment_date(get_option('time_format') ); ?> 
	    			</span>
	    		</span>
	    		<?php 
	    		$reply_class = 'cmt-reply';
			    echo preg_replace( '/comment-reply-link/', 'comment-reply-link ' . $reply_class, 
			        get_comment_reply_link(array_merge($args, array('reply_text' => esc_html__('Reply', 'luxicar-lite'), 'depth' => $depth, 'max_depth' => $args['max_depth']))), 1 ); 
			      ?>
			    <?php edit_comment_link(__('Edit', 'luxicar-lite'), '', ''); ?>

	    		<div class="comment-content">
	    			<?php comment_text(); ?>
	    		</div>
	    	</div>
		</div>
		<!-- /.entry-item --> 
<?php
} 

function luxicar_lite_get_comment_field($aria_req, $type = 'text', $id = '', $name = '', $label = '',$placeholder = '', $before = NULL, $after = NULL) {
	ob_start();
	echo wp_kses_post( $before ); ?>
	<input 
		<?php echo esc_attr($aria_req); ?>
		type="<?php echo esc_attr($type); ?>"
		value="<?php echo wp_kses_post($label); ?>"
		onfocus="if(this.value=='<?php echo wp_kses_post($label); ?>')this.value='';"
  		onblur="if(this.value=='')this.value='<?php echo wp_kses_post($label); ?>';"
		id="<?php echo esc_attr($id); ?>"
		name="<?php echo esc_attr($name); ?>"
		class="valid">
  <?php
  	echo wp_kses_post( $after );
  	return ob_get_clean();
}

function luxicar_lite_get_comment_field_message($aria_req, $id = '', $name = '', $placeholder = '') {
	ob_start(); ?>
	<textarea 
		<?php echo esc_attr($aria_req); ?>
		name="<?php echo esc_attr($name); ?>"
		id="<?php echo esc_attr($id); ?>"
		onfocus="if(this.value=='<?php echo esc_attr($placeholder); ?>')this.value='';"
		onblur="if(this.value=='')this.value='<?php echo esc_attr($placeholder); ?>';"
		class="valid"><?php echo esc_attr($placeholder); ?></textarea>
<?php
return ob_get_clean();
}

function luxicar_lite_comment_form($args = array(), $post_id = null) {
	global $post;
	if (null === $post_id) {
		$post_id = get_the_ID();
	}

	$commenter = wp_get_current_commenter();
	$user = wp_get_current_user();
	$user_identity = $user->exists() ? $user->display_name : '';
	$args = wp_parse_args($args);
	$args['format'] = current_theme_supports('html5', 'comment-form') ? 'html5' : 'xhtml';
	$req = get_option('require_name_email');
	$aria_req = ( $req ? "aria-required=true" : '' );
	$html5 = 'html5' === $args['format'];

	$fields = array();

	$fields['author'] = luxicar_lite_get_comment_field($aria_req, 'text', 'comment_name', 'author', esc_html__('Name *', 'luxicar-lite'));

	$fields['email']  = luxicar_lite_get_comment_field($aria_req, 'text', 'comment_email', 'email', esc_html__('Email *', 'luxicar-lite'));

	$fields           = apply_filters('comment_form_default_fields', $fields);

	$comment_field = luxicar_lite_get_comment_field_message($aria_req, 'comment_message', 'comment', esc_html__('Message *', 'luxicar-lite'));

	$defaults = array(
	    'fields'               => $fields,
	    'comment_field'        => $comment_field,
	    'must_log_in' 		   => '<p class="must-log-in">' . sprintf(__('You must be <a href="%s">logged in</a> to post a comment.', 'luxicar-lite'), wp_login_url(apply_filters('the_permalink', get_permalink($post_id)))) . '</p>',
	    'logged_in_as' 		   => '<p class="logged-in-as">' . sprintf(__('Logged in as <a href="%1$s">%2$s</a>. <a href="%3$s" title="Log out of this account">Log out?</a>', 'luxicar-lite'), get_edit_user_link(), $user_identity, wp_logout_url(apply_filters('the_permalink', get_permalink($post_id)))) . '</p>',
	    'comment_notes_before' => '',
	    'comment_notes_after'  => '',
	    'id_form'              => 'comments-form',
	    'id_submit' 		   => 'submit-comment',
	    'title_reply'          => esc_html__('Leave your comments', 'luxicar-lite'),
	    'title_reply_to'       => esc_html__('Leave your comments to %s', 'luxicar-lite'),
	    'cancel_reply_link'    => esc_html__('(Cancel)', 'luxicar-lite'),
	    'label_submit'         => esc_html__('POST COMMENT', 'luxicar-lite'),
	    'format'               => 'xhtml',
	    );
	$args = wp_parse_args($args, apply_filters('comment_form_defaults', $defaults));
	?>
	<?php if (comments_open($post_id)) : ?>
		<div class="widget kopa-form-widget s2 comment-respond" id="respond">
			<div class="widget-title">
				<h2>
					<?php comment_form_title($args['title_reply'], $args['title_reply_to']); ?>
		        	<?php cancel_comment_reply_link($args['cancel_reply_link']); ?>
	        	</h2>
			</div>
			<!-- /.widget-title -->
			<?php 
			if (get_option('comment_registration') && !is_user_logged_in()) : ?>
	    		<?php echo wp_kses_post( $args['must_log_in'] ); ?>
	    		<?php do_action('comment_form_must_log_in_after'); ?>
	    	<?php else : ?>
	    		<div class="widget-content">
		    		<form action="<?php echo esc_url(site_url('/wp-comments-post.php')); ?>" method="post" id="<?php echo esc_attr($args['id_form']); ?>" class="comment-form">
							<?php if(!is_user_logged_in()): ?>
								<div class="row">
								<?php 
								do_action('comment_form_before_fields'); 
								foreach ((array) $args['fields'] as $name => $field) {
									echo '<div class="col-xs-12 col-md-6">';
								    echo apply_filters("comment_form_field_{$name}", $field);
								    echo '</div>';
								}
								?>
						</div>
						<input type="text" value="Subject" onfocus="if(this.value=='Subject')this.value='';" onblur="if(this.value=='')this.value='Subject';" name="subject">
								<?php
									echo apply_filters('comment_form_field_comment', $args['comment_field']);
	    							echo wp_kses_post($args['comment_notes_after']);
							else: ?>
							<?php		
									echo apply_filters('comment_form_logged_in', $args['logged_in_as'], $commenter, $user_identity);                    
	    							do_action('comment_form_logged_in_after', $commenter, $user_identity);
	    							echo apply_filters('comment_form_field_comment', $args['comment_field']);
	    							echo wp_kses_post($args['comment_notes_after']); ?>
							<?php endif; ?>
						<input name="submit" type="submit" id="<?php echo esc_attr($args['id_submit']); ?>" class="submit" value="<?php echo esc_attr($args['label_submit']); ?>">
						<?php comment_id_fields($post_id); ?>
		    		</form>
	    		</div>
			<?php endif; ?>
		</div>
		<!-- /.kopa-form-widget -->
<?php
else :
  do_action('comment_form_comments_closed');
endif;
}
?>

