<?php
add_action('after_setup_theme', 'luxicar_lite_after_setup_theme');

function luxicar_lite_after_setup_theme() {
    global $content_width;
    $content_width = 920;

    add_theme_support('html5');
    add_theme_support('title-tag');    
    add_theme_support('post-thumbnails');
    add_theme_support('loop-pagination');
    add_theme_support('automatic-feed-links');
    add_theme_support( 'custom-logo', array(
        'height'      => 80,
        'width'       => 200,
        'flex-height' => true,
        'flex-width'  => true,
        'header-text' => array( 'site-title', 'site-description' ),
    ) );

    register_nav_menus(array(
        'main-nav'   => esc_html__('Main Menu', 'luxicar-lite'),
        'footer-nav' => esc_html__('Footer Menu', 'luxicar-lite'),
        )
    );


    if (!is_admin()){
        add_action('wp_enqueue_scripts', 'luxicar_lite_enqueue_scripts');
        add_filter('excerpt_length', 'luxicar_lite_custom_excerpt_lenght');
        add_filter('luxicar_lite_get_footer', 'luxicar_lite_get_footer');
        add_filter('luxicar_lite_get_sidebar', 'luxicar_lite_set_sidebar', 10, 2);
        remove_filter('term_description','wpautop');
        add_filter( 'body_class', 'luxicar_lite_set_body_class' );
    }
    add_action( 'admin_enqueue_scripts', 'luxicar_lite_add_custom_admin_css' );
    add_image_size( 'widget-85x72', 85, 72, true );
    luxicar_lite_register_new_image_sizes();
    load_theme_textdomain('luxicar-lite', get_template_directory() . '/languages');   
}

function luxicar_lite_enqueue_scripts(){
    global $wp_styles, $is_IE;
    $dir = get_template_directory_uri();

    wp_enqueue_style('bootstrap', $dir . "/css/bootstrap.css", array(), NULL);
    wp_enqueue_style('font-awesome', $dir . "/css/font-awesome.css", array(), NULL);
    wp_enqueue_style('jquery-navgoco', $dir . "/css/jquery.navgoco.css", array(), NULL);
    wp_enqueue_style('superfish', $dir . "/css/superfish.css", array(), NULL);
    wp_enqueue_style('flexslider', $dir . "/css/flexslider.css", array(), NULL);
    wp_enqueue_style('slick', $dir . "/css/slick.css", array(), NULL);
    wp_enqueue_style('sb-search', $dir . "/css/sb-search.css", array(), NULL);
    wp_enqueue_style('pro-bars', $dir . "/css/pro-bars.css", array(), NULL);
    wp_enqueue_style('bootstrap-datetimepicker', $dir . "/css/bootstrap-datetimepicker.css", array(), NULL);
    wp_enqueue_style('luxicar-lite-fonts', luxicar_lite_fonts_url(), array(), null );
    wp_enqueue_style('luxicar-lite-style', get_stylesheet_uri(), array(), NULL);
      
    if (is_singular())
        wp_enqueue_script('comment-reply');

    if ($is_IE) {
        wp_register_style('luxicar-ie', "{$dir}/css/ie/ie.css", array(), NULL);
        wp_enqueue_style('luxicar-ie');
        $wp_styles->add_data('luxicar-ie', 'conditional', 'lt IE 9');

        wp_register_style('luxicar-ie9', "{$dir}/css/ie/ie9.css", array(), NULL);
        wp_enqueue_style('luxicar-ie9');
        $wp_styles->add_data('luxicar-ie9', 'conditional', 'IE 9');
    }

    /* JAVASCRIPTS */
    wp_enqueue_script('modernizr-custom', $dir . '/js/modernizr.custom.js', array('jquery'), null);
    wp_enqueue_script('jquery');
    wp_enqueue_script('jquery-ui-min', $dir . '/js/jquery-ui.min.js', array('jquery'), null, true);
    wp_enqueue_script('appear-min', $dir . '/js/appear.min.js', array('jquery'), null, true);
    wp_enqueue_script('bootstrap-min', $dir . '/js/bootstrap.min.js', array('jquery'), null, true);
    wp_enqueue_script('google-map', 'http://maps.google.com/maps/api/js?sensor=true', array(), null, true);
    wp_enqueue_script('luxicar-custom', $dir . '/js/custom.js', array('jquery'), null, true);
    
    /* SEND LOCALIZATION TO FRONTEND */
    wp_localize_script('luxicar-custom', 'luxicar_lite_variable', luxicar_lite_custom_front_localization());
}

function luxicar_lite_custom_front_localization() {
    $luxicar_lite_localization = array(
        'template' => array(
            'post_id' => (is_singular()) ? get_queried_object_id() : 0,
            'cat_id'  => (is_category()) ? get_queried_object_id() : 0,
            'tag_id'  => (is_category()) ? get_queried_object_id() : 0,
            'is_home' => is_home() ? 1 : 0,
        ),
        'url' => array(
            'template_directory_uri' => get_template_directory_uri().'/',
            'ajax'                   => admin_url('admin-ajax.php')
        ),
        'validate' => array(
            'form' => array(
                'submit'  => __('SEND', 'luxicar-lite'),
                'sending' => __('SENDING...', 'luxicar-lite')
            ),
            'name' => array(
                'required'  => __('Please enter your name.', 'luxicar-lite'),
                'minlength' => __('At least {0} characters required.', 'luxicar-lite'),
            ),
            'email' => array(
                'required' => __('Please enter your email.', 'luxicar-lite'),
                'email'    => __('Please enter a valid email.', 'luxicar-lite')
            ),
            'message' => array(
                'required'  => __('Please enter a message.', 'luxicar-lite'),
                'minlength' => __('At least {0} characters required.', 'luxicar-lite'),
            ),
            'subject' => array(
                'required'  => __('Please enter a subject.', 'luxicar-lite'),
                'minlength' => __('At least {0} characters required.', 'luxicar-lite'),
            )
        ),
    );

    return $luxicar_lite_localization;
}

function luxicar_lite_add_custom_admin_css(){
    wp_register_style('luxicar-custom-admin-css', get_template_directory_uri() . '/css/custom-admin.css', false, '1.0.0' );
    wp_enqueue_style('luxicar-custom-admin-css' );
}

function luxicar_lite_get_option( $option_name, $default = null ) {
    if(function_exists('kopa_get_option')){
        return kopa_get_option($option_name, $default);
    }    
    return $default;
}

function luxicar_lite_get_template_setting($default = null) {
    if(function_exists('kopa_get_template_setting')){
        return kopa_get_template_setting();
    }    

    return $default;
}

function luxicar_lite_fonts_url() {
    $fonts_url = '';
    $fonts     = array();
    $subsets   = 'latin,latin-ext';

    /*
     * Translators: If there are characters in your language that are not supported
     * by Noto Sans, translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Montserrat font: on or off', 'luxicar-lite' ) ) {
        $fonts[] = 'Montserrat:400,700';
    }

    /*
     * Translators: If there are characters in your language that are not supported
     * by Noto Serif, translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Raleway font: on or off', 'luxicar-lite' ) ) {
        $fonts[] = 'Raleway:400,300,500,700,600';
    }

    /*
     * Translators: If there are characters in your language that are not supported
     * by Inconsolata, translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Lora font: on or off', 'luxicar-lite' ) ) {
        $fonts[] = 'Lora:400italic';
    }

    /*
     * Translators: To add an additional character subset specific to your language,
     * translate this to 'greek', 'cyrillic', 'devanagari' or 'vietnamese'. Do not translate into your own language.
     */
    $subset = _x( 'no-subset', 'Add new subset (greek, cyrillic, devanagari, vietnamese)', 'luxicar-lite' );

    if ( 'cyrillic' == $subset ) {
        $subsets .= ',cyrillic,cyrillic-ext';
    } elseif ( 'greek' == $subset ) {
        $subsets .= ',greek,greek-ext';
    } elseif ( 'devanagari' == $subset ) {
        $subsets .= ',devanagari';
    } elseif ( 'vietnamese' == $subset ) {
        $subsets .= ',vietnamese';
    }

    if ( $fonts ) {
        $fonts_url = add_query_arg( array(
            'family' => urlencode( implode( '|', $fonts ) ),
            'subset' => urlencode( $subsets ),
        ), 'https://fonts.googleapis.com/css' );
    }

    return $fonts_url;
}

function luxicar_lite_set_body_class($classes){
    if($luxicar_lite_current_layout = luxicar_lite_get_template_setting()){
        switch ($luxicar_lite_current_layout['layout_id']) {
            case 'right-sidebar':
                array_push($classes,'kopa-sub-page blog-list-page');
                break;
            case 'two-posts-left-sidebar':
            case 'masonry':
                array_push($classes,'kopa-sub-page blog-list-2-page');
                break;
            case 'one-post-left-sidebar':
                array_push($classes,'kopa-sub-page blog-list-3-page');
                break;
            case 'one-post-each-row':
                array_push($classes,'kopa-sub-page blog-list-4-page');
                break;
            case 'fullwidth':
                array_push($classes,'kopa-sub-page blog-full-width-page');
                break;
            case 'static-page':
                array_push($classes,'kopa-sub-page blog-list-page');
                break;
            case 'single-post':
                array_push($classes,'kopa-sub-page single-page');
                break;
            case 'single-portfolio':
                array_push($classes,'kopa-sub-page gallery-single-page');
                break;
            case 'single-service':
                array_push($classes,'kopa-sub-page service-single-page');
                break;
            case 'error-404':
                array_push($classes,'kopa-sub-page 404-page');
                break;
        }
    }
    return apply_filters('luxicar_lite_set_body_class', $classes);
}

function luxicar_lite_register_new_image_sizes(){
    add_image_size('luxicar-blog-one-post-each-row', 255, 161, true); //blog 4
    add_image_size('luxicar-blog-right-sidebar', 405, 240, true ); // blog 1, 2
    add_image_size('luxicar-blog-one-post-left-sidebar', 810, 320, true); // blog 3
    add_image_size('luxicar-blog-masonry', 270, 180, true ); // masonry
    add_image_size('luxicar-blog-fullwidth', 920, 420, true ); // fullwidth
    add_image_size('luxicar-related-post', 370, 210, true ); // related-post
    add_image_size('luxicar-recent-post', 100, 70, true ); // recent-post
    add_image_size('luxicar-gallery-single', 635, 350, true ); // single-gallery                   
}

function luxicar_lite_edit_comment_link( $output ) {
  $edit_class = 'cmt-reply';
  return preg_replace( '/comment-edit-link/', 'comment-edit-link ' . $edit_class, $output, 1 );
}
add_filter( 'edit_comment_link', 'luxicar_lite_edit_comment_link' );

function luxicar_lite_social_links($class){
    $string = '';
    $socials = array(
        'facebook'  => 'fa-facebook',
        'twitter'   => 'fa-twitter',
        'linkedin'  => 'fa-linkedin',
        'gplus'     => 'fa-google-plus',
        'instagram' => 'fa-instagram',
        'dribbble'   => 'fa-dribbble',
        'tumblr'    => 'fa-tumblr',
        'youtube'   => 'fa-youtube',
    );
    foreach ($socials as $social => $social_icon) {
        if(get_theme_mod( $social.'_url' )){
            $string.= '<li><a rel= "nofollow" href="'.esc_url(get_theme_mod( $social.'_url' )).'"><i class="fa '.esc_attr( $social_icon ).'"></i></a></li>';
        }
    }

    if($string){
        echo '<div '.wp_kses_post( $class ).'><ul>'.wp_kses_post($string).'</ul></div>';
    }
}

function luxicar_lite_custom_excerpt_lenght($length){
    if( is_archive() || is_search() || is_category() ) {
        $length = (int) get_theme_mod('custom_excerpt_lenght', 55 );
    }
    return $length;
}

function luxicar_lite_cat_descscription(){
    if(is_front_page()){
        echo '<h2 class="title-page">';
        echo esc_html__( 'Home Page', 'luxicar-lite' );
        echo '</h2>';
        echo '<p class="description-page">'.category_description().'</p>';
    }
    if(class_exists( 'WC_Widget')){
        if(is_shop()){
            echo '<h2 class="title-page">';
            echo esc_html__( 'Shop', 'luxicar-lite' );
            echo '</h2>';
            $desc = get_post_meta( get_option( 'woocommerce_shop_page_id' ), 'luxicar_lite_tp_description', true );
            if( $desc )
            echo '<p class="description-page">'.wp_kses_post( $desc ).'</p>';
        }
    }
    if(is_category()){
        echo '<h2 class="title-page">';
        single_cat_title();
        echo '</h2>';
        echo '<p class="description-page">'.category_description().'</p>';
    }
    if(is_singular()){
        $desc = get_post_meta( get_the_id(), 'luxicar_lite_tp_description', true );
        echo '<h2 class="title-page">'.get_the_title().'</h2>';
        if( $desc )
        echo '<p class="description-page">'.wp_kses_post( $desc ).'</p>';
    }
    if(is_404()){
       echo '<h2 class="title-page">'.esc_html__( 'Page not found', 'luxicar-lite' ).'</h2>';
    }
    if(is_search()){
        $s = get_search_query();
        echo '<h2 class="title-page">'.esc_html__( 'Search for ', 'luxicar-lite' ).$s.'</h2>';
    }
}

function luxicar_lite_get_footer($footer){
    if($luxicar_lite_current_layout = luxicar_lite_get_template_setting()){
        switch ($luxicar_lite_current_layout['layout_id']) {
            case 'error-404':
            case 'single-portfolio':
               $footer = 'extra';
                break;
        }
    }
    return $footer;
}

function luxicar_lite_get_the_excerpt_widget($post_id, $limit) {
    $the_post = get_post($post_id); //Gets post ID
    if ( $the_post ){
        $the_excerpt = $the_post->post_content; //Gets post_content to be used as a basis for the excerpt
        $the_excerpt = strip_tags(strip_shortcodes($the_excerpt)); //Strips tags and images
        $the_excerpt = wp_trim_words( $the_excerpt, $limit, '...' );
        $the_excerpt = '<p>' . $the_excerpt . '</p>';

        echo wp_kses_post( $the_excerpt );
    }
}

add_filter( 'kopa_current_tab_default', 'luxicar_lite_kopa_current_tab_default' );
add_filter( 'kopa_settings_theme_options_enable', '__return_false' );
function luxicar_lite_kopa_current_tab_default() {
    return 'sidebar-manager';
}