<?php

add_filter( 'kopa_layout_manager_settings', 'luxicar_lite_register_layouts');

function luxicar_lite_get_positions(){
	return apply_filters('luxicar_lite_get_positions', array(
		'pos_top'      => esc_html__( 'Top', 'luxicar-lite' ),
		'pos_middle'   => esc_html__( 'Middle', 'luxicar-lite' ),
		'pos_right'    => esc_html__( 'Right', 'luxicar-lite' ),
		'pos_left'     => esc_html__( 'Left', 'luxicar-lite' ),
		'pos_bottom_1' => esc_html__( 'Bottom 1', 'luxicar-lite' ),
		'pos_bottom_2' => esc_html__( 'Bottom 2', 'luxicar-lite' ),
		'pos_bottom_3' => esc_html__( 'Bottom 3', 'luxicar-lite' ),
		'pos_footer_1' => esc_html__( 'Footer 1', 'luxicar-lite' ),
		'pos_footer_2' => esc_html__( 'Footer 2', 'luxicar-lite' )
	));
}

function luxicar_lite_get_sidebars(){
	return apply_filters('luxicar_lite_get_sidebars', array(
		'pos_top'      => 'sb_top',
		'pos_middle'   => 'sb_middle',
		'pos_right'    => 'sb_right',
		'pos_left'     => 'sb_left',
		'pos_bottom_1' => 'sb_bottom_1',
		'pos_bottom_2' => 'sb_bottom_2',
		'pos_bottom_3' => 'sb_bottom_3',
		'pos_footer_1' => 'sb_footer_1',
		'pos_footer_2' => 'sb_footer_2'
	));
}

function luxicar_lite_register_layouts( $options ) {
	$positions = luxicar_lite_get_positions();
	$sidebars  = luxicar_lite_get_sidebars();

	#1: Archive
	$blog_right_sidebar = array(
		'title'     => esc_html__( 'Blog Right Sidebar', 'luxicar-lite' ),
		'preview'   => get_template_directory_uri() . '/inc/assets/images/layouts/blog_right_sidebar.png',
		'positions' => array(
			'pos_right',
			'pos_bottom_3',
			'pos_footer_1',
			'pos_footer_2'
		)
	);

	$options['blog-layout']['positions'] = $positions;
	$options['blog-layout']['layouts'] = array(		
		'right-sidebar' => $blog_right_sidebar
	);
	$options['blog-layout']['default'] = array(
		'layout_id' => 'right-sidebar',
		'sidebars'  => array(	
			'right-sidebar' => $sidebars
		)
	);

	#2: Single
	$single_post = array(
		'title'     => esc_html__( 'Single', 'luxicar-lite' ),
		'preview'   => get_template_directory_uri() . '/inc/assets/images/layouts/single.png',
		'positions' => array(	
			'pos_bottom_3',
			'pos_footer_1',
			'pos_footer_2'
		)
	);
	
	$options['post-layout']['positions'] = $positions;
	$options['post-layout']['layouts'] = array(
		'single-post'     => $single_post,
	);
	$options['post-layout']['default'] = array(
		'layout_id' => 'single-post',
		'sidebars'  => array(
			'single-post' => $sidebars	
		)
	);

	#3: Static Page
	$page = array(
		'title'     => esc_html__('Page', 'luxicar-lite'),
		'preview'   => get_template_directory_uri() . '/inc/assets/images/layouts/page.png',
		'positions' => array(
			'pos_left',
			'pos_footer_1',
			'pos_footer_2'
		)
	);

    $options['page-layout']['positions'] = $positions;
    $options['page-layout']['layouts'] = array(
        'static-page' => $page
    );
    $options['page-layout']['default'] = array(
		'layout_id' => 'static-page',
		'sidebars'  => array(
            'static-page' => $sidebars
        )
    );

	#5: Search Page
	$search = array(
		'title'     => esc_html__('Search', 'luxicar-lite'),
		'preview'   => get_template_directory_uri() . '/inc/assets/images/layouts/one-post-in-row.png',
		'positions' => array(
			'pos_left',
			'pos_right',
			'pos_footer_1',
			'pos_footer_2'
		)
	);
    
    $options['search-layout']['positions'] = $positions;
    $options['search-layout']['layouts'] = array(
        'right-sidebar'  		=> $blog_right_sidebar
    );

    $options['search-layout']['default'] = array(
		'layout_id' => 'right-sidebar',
		'sidebars'  => array(
            'right-sidebar'  		=> $sidebars
        )
	);

	#6: Error 404
	$error_404 = array(
		'title'     => esc_html__('Error Page - 404', 'luxicar-lite'),
		'preview'   => get_template_directory_uri() . '/inc/assets/images/layouts/404.png',
		'positions' => array(
			'pos_bottom_1',	
			'pos_bottom_2',	
			'pos_bottom_3',	
			'pos_footer_1',
			'pos_footer_2'
		)
	);

    $options['error404-layout']['positions'] = $positions;
    $options['error404-layout']['layouts'] = array(
        'error-404' => $error_404
    );

    $options['error404-layout']['default'] = array(
		'layout_id' => 'error-404',
		'sidebars'  => array(
            'error-404' => $sidebars
        )
    );

	return $options;
}

add_filter('kopa_layout_manager_settings', 'luxicar_lite_page_builder_remove_layout_manager', 1, 20);

function luxicar_lite_page_builder_remove_layout_manager($options){
    foreach($options as $index => $option){
        if(isset($option['id']) && in_array( $option['id'], array('frontpage-title', 'frontpage-layout'))){
            unset($options[$index]);            
        }                   
    }   
    return $options;
}

add_filter('kopa_custom_template_setting_id','luxicar_lite_remove_frontpage_layout');

function luxicar_lite_remove_frontpage_layout($setting_id){
 	if(is_front_page() && !is_home()){
  		$setting_id = 'page-layout';
 	}
 	return $setting_id;
}