<?php

/**
 * Get gallery string ids after getting matched gallery array
 * @return array of attachment ids in gallery
 * @return empty if no gallery were found
 */
function luxicar_lite_content_get_gallery_attachment_ids( $content ) {
    $gallery = luxicar_lite_content_get_gallery( $content );

    if (isset( $gallery[0] )) {
        $gallery = $gallery[0];
    } else {
        return '';
    }

    if ( isset($gallery['shortcode']) ) {
        $shortcode = $gallery['shortcode'];
    } else {
        return '';
    }

    // get gallery string ids
    preg_match_all('/ids=\"(?:\d+,*)+\"/', $shortcode, $gallery_string_ids);
    if ( isset( $gallery_string_ids[0][0] ) ) {
        $gallery_string_ids = $gallery_string_ids[0][0];
    } else {
        return '';
    }

    // get array of image id
    preg_match_all('/\d+/', $gallery_string_ids, $gallery_ids);
    if ( isset( $gallery_ids[0] ) ) {
        $gallery_ids = $gallery_ids[0];
    } else {
        return '';
    }

    return $gallery_ids;
}

function luxicar_lite_content_get_gallery($content, $enable_multi = false) {
    return luxicar_lite_content_get_media($content, $enable_multi, array('gallery'));
}

function luxicar_lite_content_get_quote($content, $enable_multi = false) {
    return luxicar_lite_content_get_media($content, $enable_multi, array('gallery'));
}

function luxicar_lite_content_get_audio($content, $enable_multi = false) {
    return luxicar_lite_content_get_media($content, $enable_multi, array('audio', 'soundcloud'));
}

function luxicar_lite_content_get_video($content, $enable_multi = false) {
    return luxicar_lite_content_get_media($content, $enable_multi, array('vimeo', 'youtube', 'video', 'embed'));
}

function luxicar_lite_content_get_media($content, $enable_multi = false, $media_types = array()) {
    $media = array();
    $regex_matches = '';
    $regex_pattern = get_shortcode_regex();
    preg_match_all('/' . $regex_pattern . '/s', $content, $regex_matches);
    foreach ($regex_matches[0] as $shortcode) {
        $regex_matches_new = '';
        preg_match('/' . $regex_pattern . '/s', $shortcode, $regex_matches_new);
        if (in_array($regex_matches_new[2], $media_types)) :
            $media[] = array(
                'shortcode' => $regex_matches_new[0],
                'type' => $regex_matches_new[2],
                'url' => $regex_matches_new[5]
                );
        if (false == $enable_multi) {
            break;
        }
        endif;
    }    return $media;
}

function luxicar_lite_get_the_excerpt($excerpt='', $content = '', $length = 0, $more = ' [...] ') {
    if ( $length ){
        $luxicar_lite_length = $length;
    } else {
        if(is_category() || is_tag() || is_home()){
            $luxicar_lite_length = intval(get_theme_mod('custom_excerpt_lenght', '10'));
        }else {
           $luxicar_lite_length = 10; 
        }
    }

    if ( empty($excerpt) ) {
        $more_arr = get_extended($content);
        if ( count($more_arr) > 0 ) {
            $temp_excerp = $more_arr['main'];
        } else {
            $temp_excerp =  $content;
        }
        $temp_excerp =  strip_tags($temp_excerp);
        $temp_excerp =  strip_shortcodes($temp_excerp);
        $luxicar_lite_excerpt = wp_trim_words($temp_excerp, $luxicar_lite_length, $more);

    } else {
        $luxicar_lite_excerpt = wp_trim_words($excerpt, $luxicar_lite_length, $more);
    }

    return apply_filters( 'luxicar_lite_filter_excerpt', $luxicar_lite_excerpt, $luxicar_lite_length, $more);
}
 
function luxicar_lite_get_post_widget_query( $instance ){
    $query = array(
        'post_type'      => 'post',
        'posts_per_page' => $instance['number'],
        'order'          => $instance['order'] == 'ASC' ? 'ASC' : 'DESC',
        'orderby'        => $instance['orderby'],
        'ignore_sticky_posts' => true
    );

    if ( $instance['categories'] ) {        
        if($instance['categories'][0] == '')
            unset($instance['categories'][0]);

        if ( $instance['categories'] ) {
            $query['tax_query'][] = array(
                'taxonomy' => 'category',
                'field'    => 'slug',
                'terms'    => $instance['categories'],
            );
        }
    }
    
    return apply_filters( 'luxicar_lite_get_post_widget_query', $query );
}
